==> jscommunicator-1.0.27.tgz: package/src/genericTransactionalSms.js <==
"use strict"

let base =  require('./base');
let types = require('./types');

class SmsGenericTransactional extends base.Base{
  constructor(request, config, appName){
    super(request, config, appName);
  }

  sendSms(referenceId, referenceType, name, to, messageType,
           body, notes= null, expiryTime=null, senderId=null){
    let job = new types.GenericTransactionalSms();
    job.reference_id = referenceId;
    job.reference_type = referenceType;
    job.name = name;
    job.mobile = to;
    job.app_name = this.appName;
    job.message_type = messageType.toUpperCase();
    job.message_text = body;
    job.notes = notes;
    job.expiry_time = expiryTime;
    job.sender_id = senderId;
    job.sms_type = 'generic_transactional';
    this.send(job, this.queueNames.sendGenericTransactionalSmsQueue, 0);
  }

  getMessagesByReferenceId(referenceId, smsTypes, callback){
    if(!Array.isArray(smsTypes)){
      throw "smsTypes should be array";
    }
    let data = {}
    data.reference_id = referenceId;
    data.sms_types = JSON.stringify(smsTypes);
    this.get(
      '/generictransactionalsms/get_messages_by_reference_id', data, (err, response)=>{
      if(err){
        callback(err);
      }
      else{
        callback(null, response);
      }
    });
  }

  isMessageSentOfTypeForRecipient(messageType, mobile, callback){
    let data = {};
    data.message_type = messageType;
    data.mobile = mobile;
    const response = this.get(
      '/generictransactionalsms/is_msg_sent_of_type_for_recipient', data, (err, response)=>{
        if(err){
          callback(err);
        }
        else{
          callback(null, response);
        }
      });
  }

  getMessageCountByType(messageType, startDate, endDate, status, callback){
    let data = {};
    data.message_type = messageType;
    data.start_date = startDate;
    data.end_date = endDate;
    data.status = status;
    const response = this.get(
      '/generictransactionalsms/get_message_count_for_type', data, (err, response)=>{
        if(err){
          callback(err);
        }
        else{
          callback(null, response);
        }
      });
  }

  getMessageCountByReferenceIds(referenceIds, smsTypes, callback){
    if(!Array.isArray(referenceIds)){
      throw "referenceIds should be array";
    }
    if(!Array.isArray(smsTypes)){
      throw "smsTypes should be array";
    }
    let data = {};
    data.reference_ids = JSON.stringify(referenceIds);
    data.sms_types = JSON.stringify(smsTypes);
    const response = this.get(
      '/generictransactionalsms/get_message_count_by_reference_ids', data, (err, response)=>{
        if(err){
          callback(err);
        }
        else{
          callback(null, response);
        }
      });
  }

  validateSmsType(type){
    const allowedTypes = [
      'WEEKLY_ROI_SMS',
      'VN_DETAILS',
      'SURVEY_SMS',
      'MARKETING_APP_LINK_SMS',
      'VN_APP_PROMOTION_SMS',
      'SURVEY_VERIFICATION_SMS',
      'QIKWELL_APPOINTMENT_REMINDER_SMS',
      'OTP',
      'CONSULT_DOCTOR_REPLY_SMS',
      'CONSULT_GENERIC_SMS',
      'CONSULT_SMS_MAGIC_LINK',
      'ORDER_SMS',
      'SMS_ERROR_RESPONSE',
      'GUARANTEE_CLAIM',
      'FEEDBACK_NOTIFICATION_SMS',
      'FIT_RAY_SHARE_SMS',
      'VN_CALL_SUMMARY',
      'DX_ORDER_SMS',
      'FEEDBACK_STATUS_SMS',
      'MAGIC_LINK_SMS',
      'DX_ORDER_NOTIFICATION',
      'DX_ORDER_CREATED_CUSTOMER',
      'DX_ORDER_RESCHEDULE_CUSTOMER',
      'DX_PHLEBO_UPDATED',
      'DX_LAB_VISIT_REMAINDER',
      'DX_HOME_SAMPLE_REMAINDER',
      'DX_TEST_PREPARATION',
      'DX_REPORT_SHARED',
      'DX_ORDER_CANCELLED_EDIT_CUSTOMER',
      'DX_ORDER_CANCELLED_CUSTOMER',
      'PHR_INVITE_SMS',
      'PHR_RECORD_SHARED_SMS',
      'PHR_DAILY_UNCLAIMED_REMINDER_SMS',
      'PHR_DAILY_UNVIEWED_REMINDER_SMS',
      'PHR_UNCLAIMED_RECORDS_EXPIRY_REMINDER',
      'PHR_PAYMENT_TRANSACTION_INVITE_SMS',
      'PHR_TAX_SAVING_NOTIFICATION_SMS',
      'SOS',
      'KIOSK_PATIENT_SMS'
    ];

    if(allowedTypes.indexOf(type) < 0){
      throw "Invalid mail type";
    }
  }
}

module.exports = {
  SmsGenericTransactional: SmsGenericTransactional
}

==> jscommunicator-1.0.32.tgz: package/src/genericTransactionalSms.js <==
"use strict"

let base =  require('./base');
let types = require('./types');

class SmsGenericTransactional extends base.Base{
  constructor(request, config, appName){
    super(request, config, appName);
  }

  sendSms(referenceId, referenceType, name, to, messageType,
           body, notes= null, expiryTime=null, senderId=null,
           preview=false, failureReason=false, status=null){
    let job = new types.GenericTransactionalSms();
    job.reference_id = referenceId;
    job.reference_type = referenceType;
    job.name = name;
    job.mobile = to;
    job.app_name = this.appName;
    job.message_type = messageType.toUpperCase();
    job.message_text = body;
    job.notes = notes;
    job.expiry_time = expiryTime;
    job.sender_id = senderId;
    job.sms_type = 'generic_transactional';
    job.status = status;
    job.failure_reason = failureReason;
    let queueName = this.queueNames.sendGenericTransactionalSmsQueue;
    if (preview)
      queueName = this.queueNames.sendPreviewSmsQueue;
    this.send(job, queueName, 0);
  }

  getMessagesByReferenceId(referenceId, smsTypes, callback){
    if(!Array.isArray(smsTypes)){
      throw "smsTypes should be array";
    }
    let data = {}
    data.reference_id = referenceId;
    data.sms_types = JSON.stringify(smsTypes);
    this.get(
      '/generictransactionalsms/get_messages_by_reference_id', data, (err, response)=>{
      if(err){
        callback(err);
      }
      else{
        callback(null, response);
      }
    });
  }

  isMessageSentOfTypeForRecipient(messageType, mobile, callback){
    let data = {};
    data.message_type = messageType;
    data.mobile = mobile;
    const response = this.get(
      '/generictransactionalsms/is_msg_sent_of_type_for_recipient', data, (err, response)=>{
        if(err){
          callback(err);
        }
        else{
          callback(null, response);
        }
      });
  }

  getMessageCountByType(messageType, startDate, endDate, status, callback){
    let data = {};
    data.message_type = messageType;
    data.start_date = startDate;
    data.end_date = endDate;
    data.status = status;
    const response = this.get(
      '/generictransactionalsms/get_message_count_for_type', data, (err, response)=>{
        if(err){
          callback(err);
        }
        else{
          callback(null, response);
        }
      });
  }

  getMessageCountByReferenceIds(referenceIds, smsTypes, callback){
    if(!Array.isArray(referenceIds)){
      throw "referenceIds should be array";
    }
    if(!Array.isArray(smsTypes)){
      throw "smsTypes should be array";
    }
    let data = {};
    data.reference_ids = JSON.stringify(referenceIds);
    data.sms_types = JSON.stringify(smsTypes);
    const response = this.get(
      '/generictransactionalsms/get_message_count_by_reference_ids', data, (err, response)=>{
        if(err){
          callback(err);
        }
        else{
          callback(null, response);
        }
      });
  }

  validateSmsType(type){
    const allowedTypes = [
      'WEEKLY_ROI_SMS',
      'VN_DETAILS',
      'SURVEY_SMS',
      'MARKETING_APP_LINK_SMS',
      'VN_APP_PROMOTION_SMS',
      'SURVEY_VERIFICATION_SMS',
      'QIKWELL_APPOINTMENT_REMINDER_SMS',
      'OTP',
      'CONSULT_DOCTOR_REPLY_SMS',
      'CONSULT_GENERIC_SMS',
      'CONSULT_SMS_MAGIC_LINK',
      'ORDER_SMS',
      'SMS_ERROR_RESPONSE',
      'GUARANTEE_CLAIM',
      'FEEDBACK_NOTIFICATION_SMS',
      'FIT_RAY_SHARE_SMS',
      'VN_CALL_SUMMARY',
      'DX_ORDER_SMS',
      'FEEDBACK_STATUS_SMS',
      'MAGIC_LINK_SMS',
      'DX_ORDER_NOTIFICATION',
      'DX_ORDER_CREATED_CUSTOMER',
      'DX_ORDER_RESCHEDULE_CUSTOMER',
      'DX_PHLEBO_UPDATED',
      'DX_LAB_VISIT_REMAINDER',
      'DX_HOME_SAMPLE_REMAINDER',
      'DX_TEST_PREPARATION',
      'DX_REPORT_SHARED',
      'DX_ORDER_CANCELLED_EDIT_CUSTOMER',
      'DX_ORDER_CANCELLED_CUSTOMER',
      'PHR_INVITE_SMS',
      'PHR_RECORD_SHARED_SMS',
      'PHR_DAILY_UNCLAIMED_REMINDER_SMS',
      'PHR_DAILY_UNVIEWED_REMINDER_SMS',
      'PHR_UNCLAIMED_RECORDS_EXPIRY_REMINDER',
      'PHR_PAYMENT_TRANSACTION_INVITE_SMS',
      'PHR_TAX_SAVING_NOTIFICATION_SMS',
      'SOS',
      'KIOSK_PATIENT_SMS',
      'HOLONET_RED_ALERT',
      'PHR_DIAGNOSTICS_INVITE',
      'PHR_DIAGNOSTICS_RECORD_SHARED'
    ];

    if(allowedTypes.indexOf(type) < 0){
      throw "Invalid mail type";
    }
  }
}

module.exports = {
  SmsGenericTransactional: SmsGenericTransactional
}
